@@ -45,8 +45,8 @@ class PostNorm(nn.Module):
 
     def forward(self, x, *args, **kwargs):
         residual = x * self.scale_residual
-        x = self.fn(x, *args, **kwargs) + x
-        return self.norm(x) + residual
+        out = self.fn(x, *args, **kwargs) + residual
+        return self.norm(out)
 
 # normalization
 
